==> spandsp-docs-0.0.6-6-x86_64.pkg.tar.zst: usr/share/doc/spandsp/html/t4__rx_8h.js <==
var t4__rx_8h =
[
    [ "t4_stats_t", "structt4__stats__t.html", "structt4__stats__t" ],
    [ "t4_row_write_handler_t", "t4__rx_8h.html#abe5532ae1da9d8e19c18f11b7911308d", null ],
    [ "t4_state_t", "t4__rx_8h.html#a11827e9f163a2134336e21b2fea87e17", null ],
    [ "t4_image_compression_t", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7", [
      [ "T4_COMPRESSION_NONE", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a9130c9424a1b5e620ef8aae8a2c99d6e", null ],
      [ "T4_COMPRESSION_ITU_T4_1D", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaf82c44a88c0f764328b838aefda1762", null ],
      [ "T4_COMPRESSION_ITU_T4_2D", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a74e882f9924b284cee073ebed2c48050", null ],
      [ "T4_COMPRESSION_ITU_T6", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a556d8ebba4b64a09720e7a13954aa787", null ],
      [ "T4_COMPRESSION_ITU_T85", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a2d10114b469b55c17c2bfc5c3ec84610", null ],
      [ "T4_COMPRESSION_ITU_T85_L0", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a6ef124222b5129b82abc0b38f1bc1cbc", null ],
      [ "T4_COMPRESSION_ITU_T43", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a2d1ac591821b83d2292dcd68a3022540", null ],
      [ "T4_COMPRESSION_ITU_T45", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaf8602b5f5d320790397d037eb2fc36d", null ],
      [ "T4_COMPRESSION_ITU_T42", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaa126de86de0ffc5a312931312b1cb1a", null ],
      [ "T4_COMPRESSION_ITU_SYCC_T42", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aea7a96bf524a9b5c80efe10211e5a8c3", null ]
    ] ],
    [ "t4_image_length_t", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54", [
      [ "T4_LENGTH_STANDARD_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a72e5c7267ed337ddfbbbd3bb08dd2942", null ],
      [ "T4_LENGTH_FINE_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a3674ce8ce01187862d9ea1773f582f61", null ],
      [ "T4_LENGTH_300_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a32fe35599ac4e08c5c04edaaed38c39f", null ],
      [ "T4_LENGTH_SUPERFINE_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a6fec7804d617c6f0e112d70cc6074401", null ],
      [ "T4_LENGTH_600_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a5e60e6bd2488e239e2395772f43e20b2", null ],
      [ "T4_LENGTH_800_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54acd664d109e64b6f360b0d16a0d50b2c3", null ],
      [ "T4_LENGTH_1200_A4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54afd52760aa7ed7aa45f965af7f97f92c5", null ],
      [ "T4_LENGTH_STANDARD_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a3cc53a95770aba0daded850375a2fbcb", null ],
      [ "T4_LENGTH_FINE_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a01d42cad4b3278f6240dcd8bb09794d7", null ],
      [ "T4_LENGTH_300_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a9312ef322fb924f870c4f000a68c6658", null ],
      [ "T4_LENGTH_SUPERFINE_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a31db397bc13235e8d3d4656b953f95b3", null ],
      [ "T4_LENGTH_600_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a69bc85137c3ab2100b9a771913953f51", null ],
      [ "T4_LENGTH_800_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a8729b681280bc9598f01be3d0924dfc9", null ],
      [ "T4_LENGTH_1200_B4", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54af803b60da738a893c0abf4aea5a81a19", null ],
      [ "T4_LENGTH_STANDARD_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a10cb82c1b246498ba2800a7e4b045952", null ],
      [ "T4_LENGTH_FINE_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54aae120edb4bf5312a99cb2e9db9863477", null ],
      [ "T4_LENGTH_300_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a70fc6f997d715bfc7a4af9647c4b1c8b", null ],
      [ "T4_LENGTH_SUPERFINE_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a8e7c515487456e44d950a105719076a8", null ],
      [ "T4_LENGTH_600_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a8f9086b22d387c4f26875a6b8ee7dfcd", null ],
      [ "T4_LENGTH_800_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a55c46f21ca64e82e03f3837f8806d4a0", null ],
      [ "T4_LENGTH_1200_US_LETTER", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a6117a90dffca4c14ccc5abb803459600", null ],
      [ "T4_LENGTH_STANDARD_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54ae0bdd59f8b8360a0d61ea23f27fceaa8", null ],
      [ "T4_LENGTH_FINE_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a2eb31492afbe8e3437b000680c0f9c09", null ],
      [ "T4_LENGTH_300_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a2aeb90a744896adca102364caed73720", null ],
      [ "T4_LENGTH_SUPERFINE_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a30cb2588f998fd0fac10e16cd162b46e", null ],
      [ "T4_LENGTH_600_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a2c88db5c4755bff2a6ec3ef6869660db", null ],
      [ "T4_LENGTH_800_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a9ce25a1981253a2963714ca7667739da", null ],
      [ "T4_LENGTH_1200_US_LEGAL", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54a9cb72dd98bab894a4a581dff56338447", null ]
    ] ],
    [ "t4_image_types_t", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1", [
      [ "T4_IMAGE_TYPE_BILEVEL", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1a16df6930c2de0a57f9773b04cf1b1bcb", null ],
      [ "T4_IMAGE_TYPE_GRAY_8BIT", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1ae98ecb20c75cbed8ff9ab2d73588dcf3", null ],
      [ "T4_IMAGE_TYPE_GRAY_12BIT", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1ac4d3c16a47e435fa986dc5ba23d915f1", null ],
      [ "T4_IMAGE_TYPE_COLOUR_8BIT", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1a742a273a50082c4b4e33a0dd4ea1281b", null ],
      [ "T4_IMAGE_TYPE_COLOUR_12BIT", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1a82929aa2eaeffca3ec274654365efe7a", null ]
    ] ],
    [ "t4_image_width_t", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687", [
      [ "T4_WIDTH_R4_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a4b95b644aae496c03505cab7e152d0c8", null ],
      [ "T4_WIDTH_R4_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687ae231fd4402373f2b7717134d7c45e6b3", null ],
      [ "T4_WIDTH_R4_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687aeb74ffca22cbf94af4de7445e95539a5", null ],
      [ "T4_WIDTH_R8_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687abe127a85994a53be9593594e4d2e7285", null ],
      [ "T4_WIDTH_R8_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a22c052650a691ba3c8d4ee3e3fd4c344", null ],
      [ "T4_WIDTH_R8_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a462b65f2fcfa305e3788fdfa84b030e1", null ],
      [ "T4_WIDTH_300_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687afb005673b3419a35af62f8863397cf76", null ],
      [ "T4_WIDTH_300_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a8ca25fcf8df99d600b6ab68a27104e61", null ],
      [ "T4_WIDTH_300_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a739230793c6b68395e9e278128122574", null ],
      [ "T4_WIDTH_R16_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a4749612f10a5eaa5873741affb7375ba", null ],
      [ "T4_WIDTH_R16_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a254efcf9d01939f8cc1bf8d7277fcc78", null ],
      [ "T4_WIDTH_R16_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687ad26f3b848e886444200b85d0196f66a7", null ],
      [ "T4_WIDTH_600_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a836a4040b49935e3cd7d7d634c6b0ee1", null ],
      [ "T4_WIDTH_600_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a955a79ace3648ebc4881178227d64449", null ],
      [ "T4_WIDTH_600_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687adb3011ba86a3c7391ff37d30a027932a", null ],
      [ "T4_WIDTH_1200_A4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687ae6cb095386040c516b28d7c2a8430d5c", null ],
      [ "T4_WIDTH_1200_B4", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a771f1ea79729c1228a4d8cfca00cffe7", null ],
      [ "T4_WIDTH_1200_A3", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687a3a7d4ea5a01e94a25b66a8c0676311bd", null ]
    ] ],
    [ "t4_image_x_resolution_t", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0", [
      [ "T4_X_RESOLUTION_R4", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0ae157f60d133ddc1acfdf0c7ecb7eb0d6", null ],
      [ "T4_X_RESOLUTION_R8", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0a9ff57f1ed41d38515e1bdad21fe0c674", null ],
      [ "T4_X_RESOLUTION_300", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0a2a34b47befc0e689854bb9daf1fc773e", null ],
      [ "T4_X_RESOLUTION_R16", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0a0f6a30bd10e5b37103b26ec1da24ee86", null ],
      [ "T4_X_RESOLUTION_600", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0afbea3b36e4b72c0fe43a029551373920", null ],
      [ "T4_X_RESOLUTION_800", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0a4e7ae8e8005cc0a18aeb1fc13db55bcc", null ],
      [ "T4_X_RESOLUTION_1200", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0acbda02b84ceba3a7cdf0d6f9b01ac00d", null ]
    ] ],
    [ "t4_image_y_resolution_t", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfd", [
      [ "T4_Y_RESOLUTION_STANDARD", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfda33c08d9a8031a251c21ade76dd5f302d", null ],
      [ "T4_Y_RESOLUTION_FINE", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfda7288c6bbecd4751289b9c814d3ff06ba", null ],
      [ "T4_Y_RESOLUTION_300", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfdaf7942b9792d5f032cbe84dfd60d3a6ef", null ],
      [ "T4_Y_RESOLUTION_SUPERFINE", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfda5940d81c578cdcd82515fc54bebba9e0", null ],
      [ "T4_Y_RESOLUTION_600", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfdaab7e4823bfe049141b3e83a5d4eb266a", null ],
      [ "T4_Y_RESOLUTION_800", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfda778bf2dd9f97cd87bfd7f361b6ff88c7", null ],
      [ "T4_Y_RESOLUTION_1200", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfda9c56a34802bdcd5271b233e008e19648", null ]
    ] ],
    [ "t4_encoding_to_str", "t4__rx_8h.html#a68697893fe59a45380277ebee2f0549e", null ],
    [ "t4_rx_end_page", "t4__rx_8h.html#afcf26aacf661adafe7315d7b86d2e282", null ],
    [ "t4_rx_free", "t4__rx_8h.html#a72cbc78a3d647d1740da91c8d5eced09", null ],
    [ "t4_rx_get_transfer_statistics", "t4__rx_8h.html#a9f041b8e0a3120577cd5cd5e62162f9f", null ],
    [ "t4_rx_init", "t4__rx_8h.html#abe10848a0c2252056bce008cd705276d", null ],
    [ "t4_rx_put_bit", "t4__rx_8h.html#aac3807fe6e16dba4a1340db04965c5ac", null ],
    [ "t4_rx_put_byte", "t4__rx_8h.html#a0902fc1d2a4974c92659a14d1ad65494", null ],
    [ "t4_rx_put_chunk", "t4__rx_8h.html#a3a3b1c3bbd5640190bc29e75c753a390", null ],
    [ "t4_rx_release", "t4__rx_8h.html#ab0b26bec39007588bb87b1bde8e6b12f", null ],
    [ "t4_rx_set_dcs", "t4__rx_8h.html#ae636bf95b2dd9940c4abf23c151d927b", null ],
    [ "t4_rx_set_far_ident", "t4__rx_8h.html#a0e836d3fdc2a5c06387e32a585832a3b", null ],
    [ "t4_rx_set_image_width", "t4__rx_8h.html#a94e62c99ec6573f75b32ddcc4f7dd85f", null ],
    [ "t4_rx_set_model", "t4__rx_8h.html#a55ea90447fcdb65bc0d65f7be2371bb0", null ],
    [ "t4_rx_set_row_write_handler", "t4__rx_8h.html#a0db4808c3f7726ddd3fd9bf85b32abca", null ],
    [ "t4_rx_set_rx_encoding", "t4__rx_8h.html#a7d25fa0340bba7278b2b292127a8e079", null ],
    [ "t4_rx_set_sub_address", "t4__rx_8h.html#a028accee07b1eff5b8c6fc1521f578ed", null ],
    [ "t4_rx_set_vendor", "t4__rx_8h.html#adb8ba98c7a913738cad422573b57d1b3", null ],
    [ "t4_rx_set_x_resolution", "t4__rx_8h.html#a412cb2ebe756eb224919a6fe98f46ee6", null ],
    [ "t4_rx_set_y_resolution", "t4__rx_8h.html#ae8199e3c4b4febe27f1ad424797dde55", null ],
    [ "t4_rx_start_page", "t4__rx_8h.html#a0a3779e20ba7b63e276feb8a10411a30", null ]
];

==> spandsp-docs-0.0.6-7-x86_64.pkg.tar.zst: usr/share/doc/spandsp/html/t4__rx_8h.js <==
var t4__rx_8h =
[
    [ "t4_stats_t", "structt4__stats__t.html", "structt4__stats__t" ],
    [ "t4_row_write_handler_t", "t4__rx_8h.html#abe5532ae1da9d8e19c18f11b7911308d", null ],
    [ "t4_state_t", "t4__rx_8h.html#a11827e9f163a2134336e21b2fea87e17", null ],
    [ "t4_image_compression_t", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7", [
      [ "T4_COMPRESSION_NONE", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a9130c9424a1b5e620ef8aae8a2c99d6e", null ],
      [ "T4_COMPRESSION_ITU_T4_1D", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaf82c44a88c0f764328b838aefda1762", null ],
      [ "T4_COMPRESSION_ITU_T4_2D", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a74e882f9924b284cee073ebed2c48050", null ],
      [ "T4_COMPRESSION_ITU_T6", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a556d8ebba4b64a09720e7a13954aa787", null ],
      [ "T4_COMPRESSION_ITU_T85", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a2d10114b469b55c17c2bfc5c3ec84610", null ],
      [ "T4_COMPRESSION_ITU_T85_L0", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a6ef124222b5129b82abc0b38f1bc1cbc", null ],
      [ "T4_COMPRESSION_ITU_T43", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7a2d1ac591821b83d2292dcd68a3022540", null ],
      [ "T4_COMPRESSION_ITU_T45", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaf8602b5f5d320790397d037eb2fc36d", null ],
      [ "T4_COMPRESSION_ITU_T42", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aaa126de86de0ffc5a312931312b1cb1a", null ],
      [ "T4_COMPRESSION_ITU_SYCC_T42", "t4__rx_8h.html#a05fac29a43b4d160c961db06c3e827e7aea7a96bf524a9b5c80efe10211e5a8c3", null ]
    ] ],
    [ "t4_image_length_t", "t4__rx_8h.html#a93c93a73e2308fe351702c92efc32d54", null ],
    [ "t4_image_types_t", "t4__rx_8h.html#a2741bc2c30a0ef1b8a9757614713acc1", null ],
    [ "t4_image_width_t", "t4__rx_8h.html#a131a152a92f6eda35d26cdc94f5f1687", null ],
    [ "t4_image_x_resolution_t", "t4__rx_8h.html#a0f9fcb9faa10f23403fbe087b5646ba0", null ],
    [ "t4_image_y_resolution_t", "t4__rx_8h.html#aa0320cce8e2380cd0914572ddf3fdcfd", null ],
    [ "t4_encoding_to_str", "t4__rx_8h.html#a68697893fe59a45380277ebee2f0549e", null ],
    [ "t4_rx_end_page", "t4__rx_8h.html#afcf26aacf661adafe7315d7b86d2e282", null ],
    [ "t4_rx_free", "t4__rx_8h.html#a72cbc78a3d647d1740da91c8d5eced09", null ],
    [ "t4_rx_get_transfer_statistics", "t4__rx_8h.html#a9f041b8e0a3120577cd5cd5e62162f9f", null ],
    [ "t4_rx_init", "t4__rx_8h.html#abe10848a0c2252056bce008cd705276d", null ],
    [ "t4_rx_put_bit", "t4__rx_8h.html#aac3807fe6e16dba4a1340db04965c5ac", null ],
    [ "t4_rx_put_byte", "t4__rx_8h.html#a0902fc1d2a4974c92659a14d1ad65494", null ],
    [ "t4_rx_put_chunk", "t4__rx_8h.html#a3a3b1c3bbd5640190bc29e75c753a390", null ],
    [ "t4_rx_release", "t4__rx_8h.html#ab0b26bec39007588bb87b1bde8e6b12f", null ],
    [ "t4_rx_set_dcs", "t4__rx_8h.html#ae636bf95b2dd9940c4abf23c151d927b", null ],
    [ "t4_rx_set_far_ident", "t4__rx_8h.html#a0e836d3fdc2a5c06387e32a585832a3b", null ],
    [ "t4_rx_set_image_width", "t4__rx_8h.html#a94e62c99ec6573f75b32ddcc4f7dd85f", null ],
    [ "t4_rx_set_model", "t4__rx_8h.html#a55ea90447fcdb65bc0d65f7be2371bb0", null ],
    [ "t4_rx_set_row_write_handler", "t4__rx_8h.html#a0db4808c3f7726ddd3fd9bf85b32abca", null ],
    [ "t4_rx_set_rx_encoding", "t4__rx_8h.html#a7d25fa0340bba7278b2b292127a8e079", null ],
    [ "t4_rx_set_sub_address", "t4__rx_8h.html#a028accee07b1eff5b8c6fc1521f578ed", null ],
    [ "t4_rx_set_vendor", "t4__rx_8h.html#adb8ba98c7a913738cad422573b57d1b3", null ],
    [ "t4_rx_set_x_resolution", "t4__rx_8h.html#a412cb2ebe756eb224919a6fe98f46ee6", null ],
    [ "t4_rx_set_y_resolution", "t4__rx_8h.html#ae8199e3c4b4febe27f1ad424797dde55", null ],
    [ "t4_rx_start_page", "t4__rx_8h.html#a0a3779e20ba7b63e276feb8a10411a30", null ]
];
